import { FunctionOptions, Runtime } from 'aws-cdk-lib/aws-lambda';
import { Construct } from "constructs";
import { BundlingOptions } from "aws-cdk-lib";
import { FunctionAlarmProps, ObservedFunction } from "./observed-function";
/**
 * Properties for PythonFunction.
 */
export interface PythonFunctionProps extends FunctionOptions, FunctionAlarmProps {
    /**
     * Path to the source of the function.
     *
     * Example: path.join(__dirname, '..', 'mylambda')
     */
    readonly entry: string;
    /**
     * The path (relative to entry) to the index file containing the exported handler.
     *
     * @default 'index.py'
     */
    readonly index?: string;
    /**
     * The name of the exported handler in the index file.
     *
     * @default 'handler'
     */
    readonly handler?: string;
    /**
     * Bundling options to use for this function. Use this to specify custom bundling options like
     * the bundling Docker image, asset hash type, custom hash, architecture, etc.
     *
     * @default
     */
    readonly bundling?: BundlingOptions;
    /**
     * The runtime environment. Only runtimes of the Python family are supported.
     *
     * @default Runtime.PYTHON_3_9
     */
    readonly runtime?: Runtime;
}
/**
 * Python based Lambda Function
 */
export declare class PythonFunction extends ObservedFunction {
    /**
     * Creates a new Lambda Function
     */
    constructor(scope: Construct, id: string, props: PythonFunctionProps);
}
